pub struct SystemStatsResponse {
pub total_sessions: u64,
pub active_sessions: u64,
pub total_streams: u64,
pub active_streams: u64,
pub total_frames: u64,
pub total_bytes: u64,
pub average_session_duration_seconds: f64,
pub frames_per_second: f64,
pub bytes_per_second: f64,
pub uptime_seconds: u64,
}Expand description
System statistics response
Fields
total_sessions: u64Total number of sessions ever created.
active_sessions: u64Number of sessions currently active.
total_streams: u64Total number of streams ever created.
active_streams: u64Number of streams currently active.
total_frames: u64Total number of frames ever emitted.
total_bytes: u64Total number of payload bytes ever emitted.
average_session_duration_seconds: f64Average session lifetime in seconds across completed sessions.
frames_per_second: f64Throughput in frames emitted per second across the system.
bytes_per_second: f64Throughput in payload bytes emitted per second across the system.
uptime_seconds: u64Number of seconds the system has been running.